==> piwigo-2.1.5.zip: piwigo/plugins/LocalFilesEditor/language/he_IL/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'הגדרות מקומיות';
$lang['locfiledit_onglet_css'] = 'גיליונות סגנון מדורגים(CSS)';
$lang['locfiledit_onglet_tpl'] = 'תבניות';
$lang['locfiledit_onglet_lang'] = 'ספות';
$lang['locfiledit_onglet_plug'] = 'תוסף אישי';
$lang['locfiledit_cant_save'] = 'לא ניתן לשנות את הקובץ. בדוק אם לתיקיה "include/" יש הרשאות לכתיבה (chmod).';
$lang['locfiledit_newfile'] = 'הקובץ לא קיים, הקובץ ייווצר על ידי עורך הקבצים המקומיים (localfile)';
$lang['locfiledit_save_config'] = 'הקובץ נכתב בהצלחה.';
$lang['locfiledit_show_default'] = 'הצג את ההפניה לקובץ: ';
$lang['locfiledit_save_bak'] = 'עותק גיבוי יווצר בעת השמירה.';
$lang['locfiledit_saved_bak'] = 'קובץ גיבוי שנוצר (%s)';
$lang['locfiledit_save_file'] = 'שמור קובץ';
$lang['locfiledit_choose_file'] = 'בחר את הקובץ לעריכה';
$lang['locfiledit_edit'] = 'ערוך';
$lang['locfiledit_restore'] = 'שחזר את קובץ הגיבוי';
$lang['locfiledit_restore_confirm'] = 'אשר בבקשה? שיחזור קובץ הגיבוי לא יהיה אפקטיבי עד השמירה הבאה.';
$lang['locfiledit_bak_loaded1'] = 'קובץ גיבוי נטען.';
$lang['locfiledit_bak_loaded2'] = 'אתה חייב לשמור את הקובץ בכדי לשחזר.';
$lang['locfiledit_syntax_error'] = 'שגיאה תחבירית! לא ניתן לשמור את הקובץ.';
$lang['locfiledit_enable_editarea'] = 'אפשר עריכה';
$lang['locfiledit_disable_editarea'] = 'בטל עריכה';
$lang['locfiledit_new_tpl'] = 'צור קובץ חדש';
$lang['locfiledit_new_filename'] = 'שם הקובץ';
$lang['locfiledit_model'] = 'דגם';
$lang['locfiledit_empty_page'] = 'דף ריק';
$lang['locfiledit_parent_directory'] = 'מקור';
$lang['locfiledit_filename_error'] = 'אסור תווים בשם הקובץ.';
$lang['locfiledit_file_already_exists'] = 'הקובץ כבר קיים.';
$lang['locfiledit_model_error'] = 'אתה חייב לחבחור דגם.';
$lang['locfiledit_empty_filename'] = 'אתה חייב למלא את שם הקובץ.';
$lang['locfiledit_webmaster_only'] = 'רק מנהל האתר יכול ליצור או לשנות קבצים מקומיים.';
$lang['locfiledit_filename_error'] = 'אסור להשתמש בתווים מסויימים בשם הקובץ.';

?>

==> piwigo-2.1.6.zip: piwigo/plugins/LocalFilesEditor/language/he_IL/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'הגדרות מקומיות';
$lang['locfiledit_onglet_css'] = 'גיליונות סגנון מדורגים(CSS)';
$lang['locfiledit_onglet_tpl'] = 'תבניות';
$lang['locfiledit_onglet_lang'] = 'ספות';
$lang['locfiledit_onglet_plug'] = 'תוסף אישי';
$lang['locfiledit_cant_save'] = 'לא ניתן לשנות את הקובץ. בדוק אם לתיקיה "local/" יש הרשאות לכתיבה (chmod).';
$lang['locfiledit_newfile'] = 'הקובץ לא קיים, הקובץ ייווצר על ידי עורך הקבצים המקומיים (localfile)';
$lang['locfiledit_save_config'] = 'הקובץ נכתב בהצלחה.';
$lang['locfiledit_show_default'] = 'הצג את ההפניה לקובץ: ';
$lang['locfiledit_save_bak'] = 'עותק גיבוי יווצר בעת השמירה.';
$lang['locfiledit_saved_bak'] = 'קובץ גיבוי שנוצר (%s)';
$lang['locfiledit_save_file'] = 'שמור קובץ';
$lang['locfiledit_choose_file'] = 'בחר את הקובץ לעריכה';
$lang['locfiledit_edit'] = 'ערוך';
$lang['locfiledit_restore'] = 'שחזר את קובץ הגיבוי';
$lang['locfiledit_restore_confirm'] = 'אשר בבקשה? שיחזור קובץ הגיבוי לא יהיה אפקטיבי עד השמירה הבאה.';
$lang['locfiledit_bak_loaded1'] = 'קובץ גיבוי נטען.';
$lang['locfiledit_bak_loaded2'] = 'אתה חייב לשמור את הקובץ בכדי לשחזר.';
$lang['locfiledit_syntax_error'] = 'שגיאה תחבירית! לא ניתן לשמור את הקובץ.';
$lang['locfiledit_enable_editarea'] = 'אפשר עריכה';
$lang['locfiledit_disable_editarea'] = 'בטל עריכה';
$lang['locfiledit_new_tpl'] = 'צור קובץ חדש';
$lang['locfiledit_new_filename'] = 'שם הקובץ';
$lang['locfiledit_model'] = 'דגם';
$lang['locfiledit_empty_page'] = 'דף ריק';
$lang['locfiledit_parent_directory'] = 'מקור';
$lang['locfiledit_filename_error'] = 'אסור תווים בשם הקובץ.';
$lang['locfiledit_file_already_exists'] = 'הקובץ כבר קיים.';
$lang['locfiledit_model_error'] = 'אתה חייב לחבחור דגם.';
$lang['locfiledit_empty_filename'] = 'אתה חייב למלא את שם הקובץ.';
$lang['locfiledit_webmaster_only'] = 'רק מנהל האתר יכול ליצור או לשנות קבצים מקומיים.';
$lang['locfiledit_filename_error'] = 'אסור להשתמש בתווים מסויימים בשם הקובץ.';

?>
